"""
Minimal example.
Source: https://towardsdatascience.com/dash-for-beginners-create-interactive-python-dashboards-338bfcb6ffa4

"""

from dash import html
from dash import dcc
import plotly.graph_objects as go
import plotly.express as px
import argparse
import os
from urllib.parse import urlparse, urljoin

from jupyter_dash import JupyterDash

from utils import get_session_path

parser = argparse.ArgumentParser()
parser.add_argument("--port", type=int)
args = parser.parse_args()

JupyterDash.infer_jupyter_proxy_config()
session_path = get_session_path()
proxy_base_path = f"{session_path}/proxy/{args.port}/"
app = JupyterDash(requests_pathname_prefix=proxy_base_path)  # initialising dash app
df = px.data.stocks()  # reading stock price dataset


def stock_prices():
    # Function for creating line chart showing Google stock prices over time
    fig = go.Figure([go.Scatter(x=df['date'], y=df['GOOG'], \
                                line=dict(color='firebrick', width=4), name='Google')
                     ])
    fig.update_layout(title='Prices over time',
                      xaxis_title='Dates',
                      yaxis_title='Prices'
                      )
    return fig


app.layout = html.Div(id='parent', children=[
    html.H1(id='H1', children='Styling using html components', style={'textAlign': 'center',
                                                                      'marginTop': 40, 'marginBottom': 40}),

    dcc.Graph(id='line_plot', figure=stock_prices())
]
                      )


if __name__ == '__main__':
    app.run_server(
        mode="jupyterlab", port=args.port, host="localhost"
    )
