from hashlib import md5
import os
import escapism
from subprocess import check_output

# Update the namespace below to match the namespace of the project
# This can be derived from the URL to your project
# I.e. for a renku project like 
# https://renkulab.io/projects/group1/group2/tasko.olevski/dash-jupyter-server-proxy-example
# the namespace will be group1/group2/tasko.olevski
# This is needed because I cannot determine this from within a session
namespace = "mknott"  # The gitlab project namespace

def get_safe_username():
    username = os.getenv("RENKU_USERNAME")
    if not username:
        raise ValueError("Cannot determine username for creating session path.")
    return escapism.escape(username, escape_char="-").lower()

def get_current_branch():
    return check_output(["git", "branch", "--show-current"]).decode().strip("\n\r\t'")

def get_server_name():
    """Form a 16-digit hash server ID."""
    safe_username = get_safe_username()
    project = os.getenv("PROJECT_NAME")
    if not project:
        raise ValueError("Cannot determine project name for creating session path")
    branch = get_current_branch()
    commit_sha = os.getenv("CI_COMMIT_SHA")
    if not commit_sha:
        raise ValueError("Cannot determine commit sha for creating session path")
    server_string = f"{safe_username}-{namespace}-{project}-{branch}-{commit_sha}"
    return "{username}-{project}-{hash}".format(
        username=safe_username[:10].lower(),
        project=escapism.escape(project, escape_char="-")[:24].lower(),
        hash=md5(server_string.encode()).hexdigest()[:8].lower(),
    )

def get_session_path():
    server_name = get_server_name()
    return f"/sessions/{server_name}"